@@ -16,10 +16,37 @@ from .io import rotateItems
 __all__ = [
     "WaitingBar",
     "LoggingDisabler",
-    "configLogging"
+    "configLogging",
+    "readableSize"
 ]
 
 
+def readableSize(byteSize: int, floating: int = 2, binary: bool = True) -> str:
+    """Convert bytes to human-readable string (like `-h` option in POSIX).
+
+    Args:
+        size (int): Total bytes.
+        floating (int, optional): Floating point length. Defaults to 2.
+        binary (bool, optional): Format as XB or XiB. Defaults to True.
+
+    Returns:
+        str: Human-readable string of size.
+    """
+    size = float(byteSize)
+    unit = "B"
+    if binary:
+        for unit in ["B", "kiB", "MiB", "GiB", "TiB", "PiB"]:
+            if size < 1024.0 or unit == "PiB":
+                break
+            size /= 1024.0
+        return f"{size:.{floating}f}{unit}"
+    for unit in ["B", "kB", "MB", "GB", "TB", "PB"]:
+        if size < 1000.0 or unit == "PB":
+            break
+        size /= 1000.0
+    return f"{size:.{floating}f}{unit}"
+
+
 class WaitingBar(DecoratorContextManager):
     """A CLI tool for printing waiting bar.
 
@@ -135,11 +162,11 @@ def configLogging(logDir: str, rootName: str = "", level: str = logging.INFO, lo
         "version": 1,
         "formatters": {
             "full": {
-                "format": "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+                "format": r"%(asctime)s - %(name)s - %(levelname)s - %(message)s"
             },
             "simple": {
-                "format": "%(asctime)s - %(message)s",
-                "datefmt": "%m/%d %H:%M:%S"
+                "format": r"%(asctime)s - %(message)s",
+                "datefmt": r"%m/%d %H:%M:%S"
             }
         },
         "filters": {
@@ -149,10 +176,12 @@ def configLogging(logDir: str, rootName: str = "", level: str = logging.INFO, lo
         },
         "handlers": {
             "console": {
-                "class": "logging.StreamHandler",
+                "class": "rich.logging.RichHandler",
                 "level": level,
-                "formatter": "simple",
-                "stream": "ext://sys.stdout"
+                "markup": True,
+                "rich_tracebacks": True,
+                "tracebacks_show_locals": True,
+                "log_time_format": r"%m/%d %H:%M"
             },
             "info_file": {
                 "class": "logging.FileHandler",
