@@ -10,8 +10,8 @@ class Handler(abc.ABC):
         super().__init__()
         self._format = format
 
-    def to(self, device):
-        pass
+    def to(self, device: Any) -> "Handler":
+        return self
 
     @property
     def Length(self) -> int:
@@ -21,13 +21,9 @@ class Handler(abc.ABC):
     def Accumulated(self) -> float:
         return self.accumulated
 
-    @Length.setter
-    def Length(self, length: int):
-        self.length = length
-
-    @Accumulated.setter
-    def Accumulated(self, accumulated: float):
-        self.accumulated = accumulated
+    @property
+    def Result(self) -> float:
+        return self.accumulated / self.length
 
     def __call__(self, *args: Any, **kwds: Any):
         results = self.handle(*args, **kwds)
@@ -55,3 +51,10 @@ class Meters:
                 for handler
                     in self._handlers
         }
+
+    def results(self, reset: bool = False):
+        return {
+            handler.__class__.__name__: handler.Result
+                for handler
+                    in self._handlers
+        }
